%define pypi_name twisted

# comment out if not pre rel
#%%define prerel rc1

%global tarball_version %%(tr -d '~' <<< %{version})

Name:           python-twisted
Version:        24.3.0
Release:        %mkrel 2
Summary:        Event-based framework for internet applications
License:        MIT
Group:          Development/Python
URL:            https://www.twistedmatrix.com/
Source0:        %{pypi_source %{pypi_name} %{tarball_version}}
# Import gobject from gi.repository for Python 3
# https://twistedmatrix.com/trac/ticket/9642
# Patch1:         0001-Import-gobject-from-gi.repository-in-Python-3.patch
# Patch2:         twisted-strict-gtk-ver.patch
Patch1:         CVE-2024-41671-1.patch
Patch2:         CVE-2024-41671-2.patch
Patch3:         CVE-2024-41671-3.patch
Patch4:         CVE-2024-41671-4.patch
Patch5:         CVE-2024-41671-5.patch
Patch6:         CVE-2024-41671-6.patch
Patch7:         CVE-2024-41671-7.patch
Patch8:         CVE-2024-41810-1.patch
Patch9:         CVE-2024-41810-2.patch
Patch10:        CVE-2024-41810-3.patch
Patch11:        CVE-2024-41810-4.patch
Patch12:        CVE-2024-41810-5.patch
Patch13:        CVE-2024-41810-6.patch
BuildArch:      noarch
BuildRequires:  python3-cython
BuildRequires:  pkgconfig(python3)

%description
Twisted is a framework, written in Python, for writing networked
applications. It includes implementations of a number of commonly used
network services such as a web server, an IRC chat server, a mail
server, a relational database interface and an object broker. Developers
can build applications using all of these services as well as custom
services that they write themselves. Twisted also includes a user
authentication system that controls access to services and provides
services with user context information to implement their own security
models.

%package -n python3-twisted
Summary:        Python3 event-based framework for internet applications
Group:          Development/Python
%{?python_provide:%python_provide python3-twisted}
Recommends:     python3dist(pyopenssl)
Recommends:     python3dist(service-identity)
Recommends:     python3dist(idna)
Recommends:     python3dist(pyasn1)
Recommends:     python3dist(cryptography)
Recommends:     python3dist(pyserial)

%{?python_extras_subpkg:Recommends:  python3-twisted+tls}
%{!?python_extras_subpkg:Recommends: python3dist(service-identity) >= 18.1}

%description -n python3-twisted
Twisted is a framework, written in Python3, for writing networked
applications. It includes implementations of a number of commonly used
network services such as a web server, an IRC chat server, a mail
server, a relational database interface and an object broker. Developers
can build applications using all of these services as well as custom
services that they write themselves. Twisted also includes a user
authentication system that controls access to services and provides
services with user context information to implement their own security
models.

%{?python_extras_subpkg:%python_extras_subpkg -n python3-twisted -i %{python3_sitelib}/*.dist-info tls}

%prep
%autosetup -n %{pypi_name}-%{tarball_version} -p1

# drop bundled egg-info
rm -rf src/*.egg-info/

%generate_buildrequires
%pyproject_buildrequires

%build
%pyproject_wheel

%install
# no-manual-page-for-binary
mkdir -p %{buildroot}%{_mandir}/man1/
for s in conch core mail; do
cp -a docs/$s/man/*.1 %{buildroot}%{_mandir}/man1/
done

%pyproject_install
# Packages that install arch-independent twisted plugins install here.
# https://bugzilla.redhat.com/show_bug.cgi?id=1252140
mkdir -p %{buildroot}%{python3_sitelib}/twisted/plugins

# Move and symlink python3 scripts
# no-manual-page-for-binary: man page is trial and twistd
mv %{buildroot}%{_bindir}/trial %{buildroot}%{_bindir}/trial-%{python3_version}
ln -s ./trial-%{python3_version} %{buildroot}%{_bindir}/trial-3
ln -s ./trial-%{python3_version} %{buildroot}%{_bindir}/trial

mv %{buildroot}%{_bindir}/twistd %{buildroot}%{_bindir}/twistd-%{python3_version}
ln -s ./twistd-%{python3_version} %{buildroot}%{_bindir}/twistd-3
ln -s ./twistd-%{python3_version} %{buildroot}%{_bindir}/twistd

%pyproject_save_files twisted
echo "%ghost %{python3_sitelib}/twisted/plugins/dropin.cache" >> %{pyproject_files}

%check
# can't get this to work within the buildroot yet due to multicast
# https://twistedmatrix.com/trac/ticket/7494
#PATH=%{buildroot}%{_bindir}:$PATH PYTHONPATH=%{buildroot}%{python3_sitelib} %{buildroot}%{_bindir}/trial twisted ||:

%files -n python3-twisted -f %{pyproject_files}
%doc NEWS.rst README.rst
%license LICENSE
%{_bindir}/trial-3*
%{_bindir}/twistd-3*
%{_bindir}/cftp
%{_bindir}/ckeygen
%{_bindir}/conch
%{_bindir}/mailmail
%{_bindir}/pyhtmlizer
%{_bindir}/tkconch
%{_bindir}/trial
%{_bindir}/twist
%{_bindir}/twistd
%{_mandir}/man1/cftp.1*
%{_mandir}/man1/ckeygen.1*
%{_mandir}/man1/conch.1*
%{_mandir}/man1/mailmail.1*
%{_mandir}/man1/pyhtmlizer.1*
%{_mandir}/man1/tkconch.1*
%{_mandir}/man1/trial.1*
%{_mandir}/man1/twistd.1*


%changelog
* Mon Feb 10 2025 ns80 <ns80> 24.3.0-2.mga10
+ Revision: 2146625
- add patches from Ubuntu for CVE-2024-41671 and CVE-2024-41810 (mga#33807)

* Tue Jun 11 2024 papoteur <papoteur> 24.3.0-1.mga10
+ Revision: 2072627
- new version 24.3.0

* Tue Dec 26 2023 wally <wally> 22.10.0-4.mga10
+ Revision: 2021775
- another rebuild for py3.12 due to missing pkgs
- drop unneeded shebang fix

* Thu Dec 21 2023 tv <tv> 22.10.0-3.mga10
+ Revision: 2020741
- Fix pathfix.py path
- Rebuild for python 3.12

* Sun Jan 15 2023 wally <wally> 22.10.0-2.mga9
+ Revision: 1933595
- new version 22.10.0 final

* Wed Nov 30 2022 papoteur <papoteur> 22.10.0-1rc1.mga9
+ Revision: 1913231
+ rebuild (emptylog)

* Tue Nov 29 2022 papoteur <papoteur> 22.10.0rc1-1.mga9
+ Revision: 1912614
- new 22.10.0rc1 (mga#31140)

* Tue May 03 2022 papoteur <papoteur> 22.4.0-1.mga9
+ Revision: 1855567
- Update to 22.4.0 (mga#30067)
+ joequant <joequant>
- fix spec to use pyproject

* Sun Feb 06 2022 wally <wally> 21.7.0-3.mga9
+ Revision: 1772201
- add patch for strict Gtk3 typelib requires

* Sun Feb 06 2022 wally <wally> 21.7.0-2.mga9
+ Revision: 1772146
- rebuild for python3.10

* Thu Jan 20 2022 wally <wally> 21.7.0-1.mga9
+ Revision: 1769224
- new version 21.7.0

* Fri Apr 02 2021 wally <wally> 21.2.0-5.mga9
+ Revision: 1712686
- update recommends to be lower case

* Wed Mar 31 2021 joequant <joequant> 21.2.0-4.mga9
+ Revision: 1712106
- fix capitalization

* Fri Mar 26 2021 daviddavid <daviddavid> 21.2.0-3.mga9
+ Revision: 1710279
- add python3-twisted[tls] extra subpackage

* Mon Mar 22 2021 neoclust <neoclust> 21.2.0-2.mga9
+ Revision: 1707566
- Rebuild against python 3.9

* Sun Mar 14 2021 wally <wally> 21.2.0-1.mga9
+ Revision: 1702540
- new version 21.2.0 (sync with Fedora)
- rebuild for python 3.9

* Tue Dec 08 2020 wally <wally> 20.3.0-5.mga8
+ Revision: 1654716
- simplify idna requires to avoid boolean deps
- generate cython files during the build

* Tue Dec 08 2020 wally <wally> 20.3.0-4.mga8
+ Revision: 1654711
- build python extras subpkg

* Thu Jul 16 2020 wally <wally> 20.3.0-3.mga8
+ Revision: 1606527
- add patch to drop boolean deps from generated requires

* Thu Jul 16 2020 joequant <joequant> 20.3.0-2.mga8
+ Revision: 1606442
- recompile to fix python deps

* Wed Jul 15 2020 daviddavid <daviddavid> 20.3.0-1.mga8
+ Revision: 1606245
- new version: 20.3.0

* Tue Feb 18 2020 daviddavid <daviddavid> 19.10.0-2.mga8
+ Revision: 1539457
- fix python shebangs
+ umeabot <umeabot>
- Mageia 8 Mass Rebuild

* Tue Nov 26 2019 wally <wally> 19.10.0-1.mga8
+ Revision: 1462953
- new version 19.10.0

* Fri Oct 11 2019 tv <tv> 19.7.0-4.mga8
+ Revision: 1451720
- rebuild with python 3.8

* Thu Sep 05 2019 wally <wally> 19.7.0-3.mga8
+ Revision: 1437671
- switch optional deps to recommends
- update optional deps

* Wed Sep 04 2019 wally <wally> 19.7.0-2.mga8
+ Revision: 1437291
- really rebuild for python3.8

* Wed Sep 04 2019 wally <wally> 19.7.0-1.mga8
+ Revision: 1437281
- new version 19.7.0
- drop python2 support
- rebuild for python3.8

* Sat Apr 20 2019 wally <wally> 19.2.0-1.mga7
+ Revision: 1393950
- new version 19.2.0

* Wed Jan 09 2019 kekepower <kekepower> 18.9.0-1.mga7
+ Revision: 1353490
- Update to version 18.9.0

* Mon Jan 07 2019 wally <wally> 18.7.0-2.mga7
+ Revision: 1350919
- require service-identity

* Sat Jan 05 2019 wally <wally> 18.7.0-1.mga7
+ Revision: 1349527
- new version 18.7.0
- add patch from Fedora to add python3.7 support

* Sun Sep 23 2018 umeabot <umeabot> 17.5.0-5.mga7
+ Revision: 1300614
- Mageia 7 Mass Rebuild

* Tue Feb 20 2018 daviddavid <daviddavid> 17.5.0-4.mga7
+ Revision: 1203444
- rename python-twisted to python2-twisted

* Wed Oct 04 2017 tv <tv> 17.5.0-3.mga7
+ Revision: 1168597
- BR python-incremental thus fixing build

* Sat Aug 05 2017 pterjan <pterjan> 17.5.0-2.mga7
+ Revision: 1135671
- Rebuild for python 3.6

* Sat Jul 29 2017 daviddavid <daviddavid> 17.5.0-1.mga7
+ Revision: 1132262
- new version: 17.5.0
- python3-twisted subpackage is no more a noarch package

* Sat Aug 20 2016 philippem <philippem> 16.3.2-1.mga6
+ Revision: 1047146
- update to 16.3.2

* Thu May 19 2016 philippem <philippem> 16.2.0-1.mga6
+ Revision: 1016881
- update to 16.2.0

* Mon Apr 25 2016 philippem <philippem> 16.1.1-1.mga6
+ Revision: 1006100
- update to 16.1.1

* Mon Apr 04 2016 philippem <philippem> 16.1.0-1.mga6
+ Revision: 998390
- set python3 as noarch
- fix some files for Python3
- update to 16.1.0 - add Python3 version

* Wed Mar 16 2016 philippem <philippem> 16.0.0-1.mga6
+ Revision: 992150
- update to 16.0.0
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild

* Mon Nov 30 2015 daviddavid <daviddavid> 15.5.0-1.mga6
+ Revision: 907276
- new version: 15.5.0

* Wed Oct 07 2015 daviddavid <daviddavid> 15.4.0-2.mga6
+ Revision: 886879
- fix python2 macro

* Fri Sep 18 2015 daviddavid <daviddavid> 15.4.0-1.mga6
+ Revision: 880293
- new version: 15.4.0
- ship Twisted as a fully featured package without subpackages on the advice
- use new python macros
- introduce license macro

* Mon Jun 22 2015 daviddavid <daviddavid> 15.2.1-1.mga6
+ Revision: 839072
- new version: 15.2.1

* Wed Oct 15 2014 umeabot <umeabot> 14.0.0-4.mga5
+ Revision: 742469
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 14.0.0-3.mga5
+ Revision: 729889
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 14.0.0-2.mga5
+ Revision: 688387
- Mageia 5 Mass Rebuild

* Sat Jun 07 2014 daviddavid <daviddavid> 14.0.0-1.mga5
+ Revision: 634568
- add new required package on python-twisted-pair
+ philippem <philippem>
- update to 14.0.0, remove pythonegg(3) provides

* Mon Mar 31 2014 kharec <kharec> 13.2.0-1.mga5
+ Revision: 610801
- version 13.2.0

* Tue Oct 22 2013 neoclust <neoclust> 13.1.0-4.mga4
+ Revision: 546302
- Add missing provides

* Tue Oct 22 2013 umeabot <umeabot> 13.1.0-3.mga4
+ Revision: 544363
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 pterjan <pterjan> 13.1.0-2.mga4
+ Revision: 499580
- Rebuild to add different pythonegg provides for python 2 and 3

* Sat Oct 05 2013 philippem <philippem> 13.1.0-1.mga4
+ Revision: 491851
- Update to 13.1.0

* Sun Jan 13 2013 umeabot <umeabot> 12.2.0-2.mga3
+ Revision: 379586
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Sep 20 2012 philippem <philippem> 12.2.0-1.mga3
+ Revision: 296404
- Update to 12.2.0
+ guillomovitch <guillomovitch>
- spec cleanup
- rename distribution-specific documentation file to README.mga

* Wed Nov 23 2011 philippem <philippem> 11.1.0-1.mga2
+ Revision: 171272
- Update to 11.1.0

* Sun Jun 19 2011 kharec <kharec> 11.0.0-1.mga2
+ Revision: 110004
- new version 11.0.0

* Tue Mar 29 2011 ahmad <ahmad> 10.2.0-2.mga1
+ Revision: 78952
- add the pythonegg provides manually as this is a meta package, so the rpm
  pythonegg auto-provides scripts won't work here

* Mon Feb 21 2011 ahmad <ahmad> 10.2.0-1.mga1
+ Revision: 55818
- update to 10.2.0

* Wed Jan 19 2011 erwan <erwan> 10.1.0-2.mga1
+ Revision: 24864
- imported package python-twisted


* Tue Nov 02 2010 Crispin Boylan <crisb@mandriva.org> 10.1.0-2mdv2011.0
+ Revision: 591994
- Rebuild

* Tue Jul 20 2010 Lev Givon <lev@mandriva.org> 10.1.0-1mdv2011.0
+ Revision: 555027
- Update to 10.1.0.

* Thu Mar 04 2010 Lev Givon <lev@mandriva.org> 10.0.0-1mdv2010.1
+ Revision: 514219
- Update to 10.0.0.

* Sat Jan 02 2010 Frederik Himpe <fhimpe@mandriva.org> 9.0.0-1mdv2010.1
+ Revision: 485334
- update to new version 9.0.0

* Sat Jan 03 2009 Jérôme Soyer <saispo@mandriva.org> 8.2.0-1mdv2009.1
+ Revision: 323864
- New upstream release

* Fri Jun 13 2008 Michael Scherer <misc@mandriva.org> 8.1.0-1mdv2009.0
+ Revision: 219002
- update to 8.1.0

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Fri Aug 31 2007 Crispin Boylan <crisb@mandriva.org> 2.5.0-1mdv2008.0
+ Revision: 76791
- Update version, remove deprecated modules twisted,flow and xish

* Thu Jul 26 2007 Guillaume Rousse <guillomovitch@mandriva.org> 2.4.0-1mdv2008.0
+ Revision: 55867
- update to new version 2.4.0


* Mon Aug 22 2005 Frederic Crozat <fcrozat@mandriva.com> 2.0.0-3mdk
- Remove dependency on non existing package

* Sun May 15 2005 Michael Scherer <misc@mandriva.org> 2.0.0-2mdk
- empty pacakge cannot be uploaded, add a doc

* Sun May 15 2005 Michael Scherer <misc@mandriva.org> 2.0.0-1mdk
- package splitted upstream, so empty this one
- update license

* Sat Dec 04 2004 Michael Scherer <misc@mandrake.org> 1.3.0-4mdk
- Rebuild for new python

* Sun Nov 14 2004 Götz Waschk <waschk@linux-mandrake.com> 1.3.0-3mdk
- depend on pyOpenSSL

* Wed Sep 22 2004 Michael Scherer <misc@mandrake.org> 1.3.0-2mdk 
- split the doc from main package
- fix url of source, and remoe unused macro

* Tue Aug 17 2004 Pascal Terjan <pterjan@mandrake.org> 1.3.0-1mdk
- New version

* Thu Apr 08 2004 Pascal Terjan <pterjan@mandrake.org> 1.2.0-1mdk
- New version
- Contains .so so can't be noarch
- BuildRequires python-devel

* Mon Dec 15 2003 Erwan Velu <erwan@mandrakesoft.com> 1.1.1-1mdk
- New version

* Mon Oct 27 2003 Han Boetes <han@linux-mandrake.com> 1.1.0-1mdk
- Bump

* Wed Oct 15 2003 Han Boetes <han@linux-mandrake.com> 1.0.7-1mdk
- Cleaned up the spec
- Changed architecture
- New version
- Known bug: conch doesn't work with openssh-3.7.1

* Wed Sep 17 2003 Han Boetes <han@linux-mandrake.com> 1.0.6-2mdk
- Added pycrypto-dependency. Now we can use conch as well.
- Removed trailing whitespace.

* Sun Aug 24 2003 Frederic Lepied <flepied@mandrakesoft.com> 1.0.6-1mdk
- initial Mandrake Linux packaging

